@@ -3,7 +3,10 @@ package RiveScript;
 use strict;
 use warnings;
 
-our $VERSION = '1.42'; # Version of the Perl RiveScript interpreter.
+# Version of the Perl RiveScript interpreter. This must be on a single line!
+# See `perldoc version`
+use version; our $VERSION = version->declare('v2.0.0');
+
 our $SUPPORT = '2.0';  # Which RS standard we support.
 our $basedir = (__FILE__ =~ /^(.+?)\.pm$/i ? $1 : '.');
 
@@ -3377,6 +3380,13 @@ L<http://www.rivescript.com/> - The official homepage of RiveScript.
 
 =head1 CHANGES
 
+  2.0.0  Dec 28 2015
+  - Switch from old-style floating point version number notation to dotted
+    decimal notation. This bumps the version number to `2.0.0` because the next
+    dotted-decimal version greater than `1.42` (`v1.420.0`) is `v1.421.0` and
+    I don't like having that many digits in the version number. This release is
+    simply a version update; no breaking API changes were introduced.
+
   1.42  Nov 20 2015
   - Add configurable `unicode_punctuation` attribute to strip out punctuation
     when running in UTF-8 mode.
